@@ -118,19 +118,19 @@ void gen_serials(void)
 void print_networks()
 {
 	FILE *fpipe;
-        char command[]="/sbin/iwlist wlan0 scanning|grep ESSID:";
+    char command[]="/sbin/iwlist wlan0 scanning|grep ESSID:";
 	char line[256];
-        int counter = 0;
+    int counter = 0;
 
 	if ( !(fpipe = (FILE*)popen(command,"r")) )
 	{  // If fpipe is NULL
 		perror("Problems with pipe");
 		exit(1);
 	}
-        printf("\n\tWireless networks:\n");
+    printf("\n\tWireless networks:\n");
 	while ( fgets( line, sizeof line, fpipe))
 	{
-                printf("\t%d) %s",counter++, line+26);
+		printf("\t%d) %s",counter++, line+26);
 	}
 	pclose(fpipe);
 }
@@ -143,16 +143,16 @@ int main(int argc, char *argv[])
     
     if(argc != 2) { 
         puts("\n\t" 
-             "STkeys v0.2 - default WPA key recovery for Thomson routers"
+             "STkeys - default WPA key recovery for Thomson routers"
              "\n\t(x) June 2008 - wyse101 0x40 gmail.com"
 			 "\n\t(x) January 2010 - GetAway compiled for Maemo"); 
             
         printf("\n\tUsage: stkeys <Default Thomson SSID>\n");
 
-        print_networks();
+        //print_networks();
 
-        int n;
-        scanf ("%d",&n);
+        //int n;
+        //scanf ("%d",&n);
 
         return 0; 
     } 
